import pcqq.utils as utils

class QQStruct:
    def __init__(self):
        self.BinQQ = b''
        self.LongQQ = 0
        self.Utf8QQ = b''
        self.Redirection = 0

        self.Time = b''
        self.NickName = ''

        self.RandHead16 = b''
        self.SessionKey = b''
        self.ClientKey = b''
        self.ShareKey = b''
        self.PublicKey = b''

        self.PcKeyFor0819 = b''
        self.PcKeyTgt = b''
        self.PcKeyFor0828Send = b''
        self.PcKeyFor0828Rev = b''
        self.PcToken0038From0825 = b''
        self.PcToken0038From0818 = b''
        self.PcToken0060From0819 = b''
        self.PcToken0038From0836 = b''
        self.PcToken0088From0836 = b''

        self.LocalPcIp = b''
        self.ConnectSeverIp = b''
        self.ConnectSeverIpText = ""